#
# spec file for package arti
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           arti
#               This will be set by osc services, that will run after this.
Version:        1.1.11~0
Release:        1.1
Summary:        An implementation of Tor, in Rust.
#               If you know the license, put it's SPDX string here.
#               Alternately, you can use cargo lock2rpmprovides to help generate this.
License:        Apache-2.0 OR MIT
URL:            https://gitlab.torproject.org/tpo/core/arti
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
# Disable this line if you wish to support all platforms.
# In most situations, you will likely only target tier1 arches for user facing components.
ExclusiveArch:  %{rust_tier1_arches}

%description
An implementation of Tor, in Rust.

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%install
%{cargo_install -p crates/arti}

%check
%{cargo_test}

%files
%{_bindir}/%{name}

%changelog
* Fri Dec  8 2023 eyadlorenzo@gmail.com
- Update to version 1.1.11:
  Arti 1.1.11 continues work on support for running onion services.
  Onion services are now working in our testing, and we expect we'll
  have something testable by others in our next release.
  Arti 1.1.11 also increases our MSRV (Minimum Supported Rust Version)
  to 1.70, in accordance with our [MSRV policy].
  [#]## Onion service development
  - Correct our handling of BEGIN and END messages to bring them
    into conformance with the C Tor implementation and the specification.
    ([#1077], [!1694], [!1738])
  - In our key manager, use macros to define key specifiers, instead of
    repeating the same boilerplate code. ([#1069], [#1093], [!1710],
    [!1733])
  - Refactoring and refinement on the definitions of onion-service-related
    errors. ([!1718], [!1724], [!1750], [!1751], [!1779])
  - Add a "time-store" mechanism for (as correctly as possible) storing and loading
    future timestamps, even in the presence of system clock skew ([!1723], [!1774])
  - Implement a replay-log backend to prevent INTRODUCE replay attacks
    against onion services. ([!1725])
  - Improved encoding for key-denotators in the key manager. ([#1063],
    [#1070], [!1722])
  - Allow a single key to have more than one denotator in its path.
    ([#1112], [!1747])
  - Use an order-preserving-encryption back-end to generate
    monotonically increasing revision counters for onion service
    descriptors.  We do this to ensure a reproducible series of counters
    without leaking our clock skew.  ([#1053], [!1741], [!1744])
  - Deprecate key types for INTRODUCE-based authentication:
    C tor has never implemented this, and we do not plan to implement it
    without additional specification work. ([#1037], [!1749])
  - When establishing an introduction point, send the `intro_dos`
    extension as appropriate. ([#723], [!1740])
  - Added conversion functions and initial persistence support for
    introduction point keys. ([!1756])
  - Start work on introduction point persistence. ([!1755], [!1765]).
  - Revert to our intended configuration format for onion service proxy rules.
    ([#1058], [!1771])
  [#]## Client features
  - Backend and API code for the "ntor-v3" circuit-extension handshake.
    This handshake adds the ability to send additional options
    from the client to the relay when creating or extending a circuit,
    and will eventually be used to negotiate protocol features like
    RTT-based congestion control and UDP-over-Tor support.
    ([!1720], [!1739])
* Mon Nov 13 2023 eyadlorenzo@gmail.com
- Update to version 1.1.10:
  Arti 1.1.10 continues work on support for onion services in
  Arti. At last, we can (technically) run as an onion service...
  though not yet in a useful way. (Onion services don't yet recover
  correctly after a restart, outdated keys are not removed, and we
  are missing other important security features.)
  [#]## Breaking changes in lower-level crates
  - The [`IoErrorExt`] trait in [`tor-basic-utils`] is now
    sealed. ([!1654])
  - The [`Requestable`] trait in [`tor-dirclient`] is now sealed,
    and most of its members are now private. ([!1679])
  - In [`tor-cell`], stream and circuit IDs are now inherently
    non-zero. To represent an ID that might be zero on the wire, we
    now use
    `Option<StreamId>` or `Option<CircId>`. ([#1080], [!1697])
  - In [`tor-cell`], `CREATE2` handshake types are no longer raw
    `u16` values. ([!1703])
  - In [`tor-cert`], `encode_and_sign` now returns an
    `Ed25519EncodedCert` rather than a raw `Vec<u8>`. ([!1702])
  [#]## Client features
  - Arti can now be configured to listen for connections on
    multiple arbitrary addresses—not just `localhost`. ([!1613])
  [#]## Key manager
  - The key manager code now has improved support for generating
    keypairs, keys with derived data, and other structures needed for
    onion services. ([!1653])
  - The key manager now encodes whether a key is private or public in its
    file extension. ([!1672])
  - The key manager now disallows path components that could lead
    (under some programming errors) to directory traversal. ([!1661])
  - We can now list keys by path and type; this is important so that
    we can identify disused keys and eventually expire them. ([!1677])
  See https://gitlab.torproject.org/tpo/core/arti/-/blob/c39857a8a63200ed5ed539d1f9231b05d7da7e0d/CHANGELOG.md
  for more info
* Mon Oct 30 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints file to avoid build failures
* Wed Oct 25 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Run format_spec_file service
* Fri Oct 20 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Version 1.1.9
